@@ -47,8 +47,8 @@ void Global::deInit()
 Global::Global()
     : m_hash(new QHash<QString, FcitxConfigFileDesc *>)
     , m_connection(new FcitxQtConnection(this))
-    , m_inputmethod(0)
-    , m_keyboard(0)
+    , m_inputmethod(nullptr)
+    , m_keyboard(nullptr)
 {
     connect(m_connection, SIGNAL(connected()), this, SLOT(connected()));
     connect(m_connection, SIGNAL(disconnected()), this, SLOT(disconnected()));
@@ -93,7 +93,7 @@ void Global::connected()
     m_inputmethod->setTimeout(3000);
     m_keyboard->setTimeout(3000);
 #endif
-
+    qDebug() << "connected";
     emit connectStatusChanged(true);
 }
 
@@ -101,10 +101,10 @@ void Global::disconnected()
 {
     if (m_inputmethod)
         delete m_inputmethod;
-    m_inputmethod = 0;
+    m_inputmethod = nullptr;
     if (m_keyboard)
         delete m_keyboard;
-    m_keyboard = 0;
+    m_keyboard = nullptr;
 
     emit connectStatusChanged(false);
 }
