@@ -31,11 +31,11 @@
 namespace dcc_fcitx_configtool {
 namespace widgets {
 
-class Fcitx_TipsLabel : public Fcitx_SmallLabel
+class FcitxTipsLabel : public FcitxSmallLabel
 {
     Q_OBJECT
 public:
-    using Fcitx_SmallLabel::Fcitx_SmallLabel; // using default inheritance constructor
+    using FcitxSmallLabel::FcitxSmallLabel; // using default inheritance constructor
 };
 
 } // namespace widgets
