@@ -122,6 +122,9 @@ void IMSettingWindow::initUI()
     GSettingWatcher::instance()->bind(GSETTINGS_SHORTCUT_RESTORE, m_resetBtn);
     DFontSizeManager::instance()->bind(m_resetBtn, DFontSizeManager::T8, QFont::Normal);
     m_resetBtn->setAccessibleName(tr("Restore Defaults"));
+    //下面两行注释,和第三行文案有关联是控制中心搜索规范快捷键规范.不可以修改,不可以移动位置,下面三行要在一起
+    //~ contents_path /keyboard/Manage Input Methods
+    //~ child_page Manage Input Methods
     m_advSetKey = new QPushButton(tr("Advanced Settings"));
     GSettingWatcher::instance()->bind(GSETTINGS_ADVANCE_SETTING, m_advSetKey);
     m_advSetKey->setAccessibleName("Advanced Settings");
@@ -156,6 +159,11 @@ void IMSettingWindow::initUI()
 
     //添加界面按钮
     m_addIMBtn = new DFloatingButton(DStyle::SP_IncreaseElement, this);
+    //下面两行注释,和第三行文案有关联是控制中心搜索规范快捷键规范.不可以修改,不可以移动位置,下面三行要在一起
+    //~ contents_path /keyboard/Manage Input Methods
+    //~ child_page Manage Input Methods
+    m_addIMBtn->setToolTip(tr("Add Input Method"));
+    m_addIMBtn->setAccessibleName("AddInputMethod");
     m_addIMBtn->setMaximumHeight(50);
     GSettingWatcher::instance()->bind(GSETTINGS_ADD_IM, m_addIMBtn);
     QHBoxLayout *headLayout = new QHBoxLayout(this);
@@ -214,9 +222,9 @@ void IMSettingWindow::initConnect()
     });
 
     connect(m_advSetKey, &QAbstractButton::clicked, [ = ]() {
-        AdvancedSettingWidget *p = new AdvancedSettingWidget();
-        p->show();
-        emit requestNextPage(p);
+        AdvancedSettingWidget *advancedSettingWidget = new AdvancedSettingWidget;
+        advancedSettingWidget->show();
+        emit requestNextPage(advancedSettingWidget);
     });
     connect(IMModel::instance(), &IMModel::curIMListChanaged, this, &IMSettingWindow::onCurIMChanged);
     connect(m_addIMBtn, &DFloatingButton::clicked, this, &IMSettingWindow::onAddBtnCilcked);
