@@ -4,30 +4,61 @@
 <context>
     <name>Fcitx::AdvancedSettingWidget</name>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="105"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="104"/>
         <source>Global Config</source>
-        <translation type="unfinished"></translation>
+        <translation>Configuració global</translation>
     </message>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="108"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="107"/>
         <source>Add-ons</source>
-        <translation type="unfinished"></translation>
+        <translation>Complements</translation>
     </message>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="247"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="241"/>
         <source>None</source>
-        <translation type="unfinished">Cap</translation>
+        <translation>Cap</translation>
     </message>
 </context>
 <context>
     <name>FcitxConfigPlugin</name>
     <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="69"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="81"/>
         <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
-        <location filename="../src/fcitxconfigplugin.cpp" line="90"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="109"/>
+        <location filename="../src/fcitxconfigplugin.cpp" line="117"/>
         <source>Input Methods</source>
         <translation>Mètodes d&apos;entrada</translation>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="75"/>
+        <source>Keyboard and Language</source>
+        <translation>Llengua i teclat</translation>
+    </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
+        <source>Manage Input Methods</source>
+        <translation>Gestió dels mètodes d&apos;entrada</translation>
+    </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
+        <source>Switch input methods</source>
+        <translation>Canvia el mètode d&apos;entrada</translation>
+    </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
+        <source>Switch to the first input method</source>
+        <translation>Canvia al primer mètode d&apos;entrada</translation>
+    </message>
+    <message>
+        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
+        <source>Advanced Settings</source>
+        <translation>Configuració avançada</translation>
+    </message>
 </context>
 <context>
     <name>FcitxSettingsHead</name>
@@ -56,18 +87,16 @@
         <translation>Cerca</translation>
     </message>
     <message>
-        <location filename="../src/window/imaddwindow.cpp" line="79"/>
+        <location filename="../src/window/imaddwindow.cpp" line="80"/>
         <source>Find more in App Store</source>
         <translation>Trobeu-ne més a la Botiga d&apos;aplicacions</translation>
     </message>
     <message>
-        <location filename="../src/window/imaddwindow.cpp" line="85"/>
         <location filename="../src/window/imaddwindow.cpp" line="86"/>
         <source>Add</source>
         <translation>Afegeix</translation>
     </message>
     <message>
-        <location filename="../src/window/imaddwindow.cpp" line="87"/>
         <location filename="../src/window/imaddwindow.cpp" line="88"/>
         <source>Cancel</source>
         <translation>Cancel·la</translation>
@@ -76,18 +105,18 @@
 <context>
     <name>IMSettingWindow</name>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="116"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="115"/>
         <source>Switch input methods</source>
         <translation>Canvia el mètode d&apos;entrada</translation>
     </message>
     <message>
-        <location filename="../src/window/imsettingwindow.cpp" line="121"/>
+        <location filename="../src/window/imsettingwindow.cpp" line="119"/>
         <source>Switch to the first input method</source>
         <translation>Canvia al primer mètode d&apos;entrada</translation>
     </message>
     <message>
+        <location filename="../src/window/imsettingwindow.cpp" line="121"/>
         <location filename="../src/window/imsettingwindow.cpp" line="124"/>
-        <location filename="../src/window/imsettingwindow.cpp" line="127"/>
         <source>Restore Defaults</source>
         <translation>Restaura els valors per defecte</translation>
     </message>
@@ -95,6 +124,8 @@
         <location filename="../src/window/imsettingwindow.cpp" line="128"/>
         <source>Advanced Settings</source>
         <translation>Configuració avançada</translation>
+        <extra-child_page>Manage Input Methods</extra-child_page>
+        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
     <message>
         <location filename="../src/window/imsettingwindow.cpp" line="138"/>
@@ -110,34 +141,41 @@
         <extra-child_page>Manage Input Methods</extra-child_page>
         <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
     </message>
+    <message>
+        <location filename="../src/window/imsettingwindow.cpp" line="165"/>
+        <source>Add Input Method</source>
+        <translation type="unfinished">Afegiu-hi un mètode d&apos;entrada</translation>
+        <extra-child_page>Manage Input Methods</extra-child_page>
+        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="554"/>
-        <location filename="../src/window/advancedsettingwidget.cpp" line="615"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="606"/>
+        <location filename="../src/window/advancedsettingwidget.cpp" line="658"/>
         <source>None</source>
-        <translation type="unfinished">Cap</translation>
+        <translation>Cap</translation>
     </message>
 </context>
 <context>
     <name>dcc_fcitx_configtool::widgets::FcitxCheckBoxSettingsItem</name>
     <message>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="450"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="596"/>
         <source>Configure</source>
-        <translation type="unfinished"></translation>
+        <translation>Configura-ho</translation>
     </message>
 </context>
 <context>
     <name>dcc_fcitx_configtool::widgets::FcitxKeyLabelWidget</name>
     <message>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="46"/>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="165"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="47"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="166"/>
         <source>None</source>
         <translation>Cap</translation>
     </message>
     <message>
-        <location filename="../src/widgets/keysettingsitem.cpp" line="52"/>
+        <location filename="../src/widgets/keysettingsitem.cpp" line="53"/>
         <source>Enter a new shortcut</source>
         <translation>Introduïu una drecera nova</translation>
     </message>
